@@ -12,13 +12,13 @@ require 'dialogs'
 require 'screenshot'
 require 'running'
 require 'scanner'
+require 'find'
 
 class RubyBox < Hildon::Window
-	require 'find'
-	
+		
 	def initialize
 		super
-		@version = "0.4.6"
+		@version = "0.4.7"
 		signal_connect( "delete_event" ) { clean_up }
 		#context = OSSO.initialize('rbox', @version)
 		@prefsdir = "#{ENV["HOME"]}/.rubybox"
@@ -121,6 +121,13 @@ class RubyBox < Hildon::Window
 			#c = ConIc::Connection.new
 			#c.signal_connect('connection_event') do | c, s |
 				#if s.status == 0
+					if (!@config["address"] || @config["address"] == "") && (!@config["nick"] || @config["nick"] == "")  
+						response = @dialogs.confirm("Warning", "Unique id is generated with md5 using your mac address.\nIt's only used to id your tablet and it can't be seen by anyone.\nPress cancel if this is a problem and continue using RubyBox\nwithout online content.")
+						if !response
+							Hildon::Banner.show_information(@rbox, "rbox", "Registeration cancelled.")
+							return
+						end
+					end
 					@config["address"] = settings["Address"]
 					@config["nick"] = settings["Your nickname"]
 					data = @net.register_nick 
